@@ -38,9 +38,9 @@ use cl3::ffi::cl_ext::cl_queue_properties_khr;
 use cl3::gl;
 #[allow(unused_imports)]
 use cl3::types::{
-    cl_bool, cl_command_queue, cl_command_queue_properties, cl_context, cl_device_id, cl_event,
-    cl_kernel, cl_map_flags, cl_mem, cl_mem_migration_flags, cl_queue_properties, cl_uint,
-    cl_ulong,
+    cl_bool, cl_command_queue, cl_command_queue_info, cl_command_queue_properties, cl_context,
+    cl_device_id, cl_event, cl_kernel, cl_map_flags, cl_mem, cl_mem_migration_flags,
+    cl_queue_properties, cl_uint, cl_ulong,
 };
 use libc::{c_void, size_t};
 use std::mem;
@@ -133,13 +133,13 @@ impl CommandQueue {
 
             let mut index = 0;
             if 0 < properties {
-                props[index] = CommandQueueInfo::CL_QUEUE_PROPERTIES as cl_queue_properties;
+                props[index] = CL_QUEUE_PROPERTIES as cl_queue_properties;
                 props[index + 1] = properties as cl_queue_properties;
                 index += 2;
             }
 
             if 0 < queue_size {
-                props[index] = CommandQueueInfo::CL_QUEUE_SIZE as cl_queue_properties;
+                props[index] = CL_QUEUE_SIZE as cl_queue_properties;
                 props[index + 1] = queue_size as cl_queue_properties;
             }
             create_command_queue_with_properties(context.get(), device_id, props.as_ptr())?
@@ -1237,43 +1237,43 @@ impl CommandQueue {
     }
 
     pub fn context(&self) -> Result<cl_context> {
-        Ok(isize::from(get_command_queue_info(
-            self.queue,
-            CommandQueueInfo::CL_QUEUE_CONTEXT,
-        )?) as cl_context)
+        Ok(isize::from(get_command_queue_info(self.queue, CL_QUEUE_CONTEXT)?) as cl_context)
     }
 
     pub fn device(&self) -> Result<cl_device_id> {
-        Ok(isize::from(get_command_queue_info(
-            self.queue,
-            CommandQueueInfo::CL_QUEUE_DEVICE,
-        )?) as cl_device_id)
+        Ok(isize::from(get_command_queue_info(self.queue, CL_QUEUE_DEVICE)?) as cl_device_id)
     }
 
     pub fn reference_count(&self) -> Result<cl_uint> {
-        Ok(get_command_queue_info(self.queue, CommandQueueInfo::CL_QUEUE_REFERENCE_COUNT)?.into())
+        Ok(get_command_queue_info(self.queue, CL_QUEUE_REFERENCE_COUNT)?.into())
     }
 
     pub fn properties(&self) -> Result<cl_ulong> {
-        Ok(get_command_queue_info(self.queue, CommandQueueInfo::CL_QUEUE_PROPERTIES)?.into())
+        Ok(get_command_queue_info(self.queue, CL_QUEUE_PROPERTIES)?.into())
     }
 
     /// CL_VERSION_2_0
     pub fn size(&self) -> Result<cl_uint> {
-        Ok(get_command_queue_info(self.queue, CommandQueueInfo::CL_QUEUE_SIZE)?.into())
+        Ok(get_command_queue_info(self.queue, CL_QUEUE_SIZE)?.into())
     }
 
     /// CL_VERSION_2_1
     pub fn device_default(&self) -> Result<cl_device_id> {
-        Ok(isize::from(get_command_queue_info(
-            self.queue,
-            CommandQueueInfo::CL_QUEUE_DEVICE_DEFAULT,
-        )?) as cl_device_id)
+        Ok(
+            isize::from(get_command_queue_info(self.queue, CL_QUEUE_DEVICE_DEFAULT)?)
+                as cl_device_id,
+        )
     }
 
     /// CL_VERSION_3_0
     pub fn properties_array(&self) -> Result<Vec<cl_ulong>> {
-        Ok(get_command_queue_info(self.queue, CommandQueueInfo::CL_QUEUE_PROPERTIES_ARRAY)?.into())
+        Ok(get_command_queue_info(self.queue, CL_QUEUE_PROPERTIES_ARRAY)?.into())
+    }
+
+    /// Get data about an OpenCL command-queue.
+    /// Calls clGetCommandQueueInfo to get the desired data about the command-queue.
+    pub fn get_data(&self, param_name: cl_command_queue_info) -> Result<Vec<u8>> {
+        Ok(get_command_queue_data(self.queue, param_name)?)
     }
 }
 
